import React from 'react';
import ButtonGroup from './ButtonGroup';
import IconButton from './IconButton';

class LinkControls extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      urlValue: '',
    };

    this.onURLChange = (event) => this.setState({ urlValue: event.target.value });
    this.confirmLink = (event) => {
      event.preventDefault();
      this.props.confirmLink(this.state.urlValue);
      $('.ui.linkify.modal').modal('hide');
      this.setState({
        urlValue: '',
      });
    };
    this.removeLink = () => {
      this.props.removeLink()
    };
  }

  promptForLink() {
    const { editorState } = this.props;
    const selection = editorState.getSelection();
    if (!selection.isCollapsed()) {
      $('.ui.linkify.modal').modal('show');
      this.setState({
        urlValue: '',
      }, () => {
        setTimeout(() => this.refs.url.focus(), 0);
      });
    }
  }

  hidePrompt(event) {
    event.preventDefault();
    $('.ui.linkify.modal').modal('hide');
  }

  onLinkInputKeyDown(event) {
    if (event.which === 13) {
      this.confirmLink(event);
    }
  }

  render() {
    return (
      <ButtonGroup>

        <div className="reveal" id="linkModal" data-reveal>
          <h1>Insert Link</h1>

          <input
            onChange={this.onURLChange}
            ref="url"
            type="text"
            value={this.state.urlValue}
            onKeyDown={this.onLinkInputKeyDown.bind(this)}
            placeholder="http://www.example.com"
          />

          <button
            type="button"
            className="ui icon button"
            onMouseDown={this.hidePrompt.bind(this)}
          >
            <i className="fa fa-times" />
          </button>
          <button
            type="button"
            className="button"
            onMouseDown={this.confirmLink}
          >
            <i className="fa fa-check" />
          </button>
          <button class="close-button" data-close aria-label="Close modal" type="button">
            <span aria-hidden="true">&times;</span>
          </button>
        </div>

        <IconButton
          onToggle={this.promptForLink.bind(this)}
          icon="link"
          active={false}
        />
        <IconButton
          onToggle={this.removeLink}
          icon="chain-broken"
          active={false}
        />
      </ButtonGroup>
    );
  }
}

export default LinkControls;
